@@ -250,16 +250,16 @@ static inline void printSimEta(char *buf, int *j) {
 void prnt_vars(int scenario, int lhs, const char *pre_str, const char *post_str, int show_ode);
 
 static inline void printCModelVars(const char *prefix) {
-  sAppend(&sbOut, "extern SEXP %smodel_vars(){\n  int pro=0;\n", prefix);
+  sAppend(&sbOut, "extern SEXP %smodel_vars(void){\n  int pro=0;\n", prefix);
   sAppend(&sbOut, "  SEXP _mv = PROTECT(_rxGetModelLib(\"%smodel_vars\"));pro++;\n", prefix);
   sAppendN(&sbOut, "  if (!_rxIsCurrentC(_mv)){\n", 28);
   sAppendN(&sbOut, "    SEXP hash    = PROTECT(allocVector(STRSXP, 1));pro++;\n", 58);
-  sAppend(&sbOut, "#define __doBuf__  sprintf(buf, \"", _mv.o+1);
+  sAppend(&sbOut, "#define __doBuf__  snprintf(buf, __doBufN__, \"", _mv.o+1);
   int off=0;
   int off2 = 0;
   for (int i = 0; i < _mv.o; i++){
     if (off != 0 && off % 4095 == 0) {
-      sAppend(&sbOut, "\"); \\\n sprintf(buf+%d, \"", off2);
+      sAppend(&sbOut, "\"); \\\n snprintf(buf+%d, __doBufN__-%d, \"", off2, off2);
     }
     off++;
     off2++;
@@ -286,7 +286,7 @@ static inline void printCModelVars(const char *prefix) {
     }
   }
   sAppendN(&sbOut, "\");\n", 4);
-  sAppend(&sbOut,"    char buf[%d];\n    __doBuf__\n#undef __doBuf__\n", off+1);
+  sAppend(&sbOut,"    char buf[%d];\n#define __doBufN__ %d\n    __doBuf__\n#undef __doBuf__\n#undef __doBufN__\n", off+1, off+1);
   sAppendN(&sbOut,"    SET_STRING_ELT(hash, 0, mkChar(buf));\n", 42);
   sAppendN(&sbOut, "    SEXP lst      = PROTECT(_rxQr(hash));pro++;\n", 48);
   sAppendN(&sbOut, "    _assign_ptr(lst);\n", 22);
@@ -303,6 +303,7 @@ static inline void printCModelVars(const char *prefix) {
 static inline void printRInit(const char *libname, const char *libname2, const char *prefix) {
   sAppend(&sbOut,"\n//Create function to call from R's main thread that assigns the required functions. Sometimes they don't get assigned.\nextern void %sassignFuns(void){\n  _assignFuns();\n}\n", prefix);
   sAppend(&sbOut,"\n//Initialize the dll to match rxode2's calls\nvoid R_init0_%s(void){\n  // Get C callables on load; Otherwise it isn't thread safe\n", libname2);
+  sAppend(&sbOut, "  R_RegisterCCallable(\"%s\",\"%sassignFuns2\", (DL_FUNC) __assignFuns2);\n", libname, prefix);
   sAppend(&sbOut, "  R_RegisterCCallable(\"%s\",\"%sassignFuns\", (DL_FUNC) %sassignFuns);\n", libname, prefix, prefix);
   sAppend(&sbOut, "  R_RegisterCCallable(\"%s\",\"%sinis\",(DL_FUNC) %sinis);\n", libname, prefix, prefix);
   sAppend(&sbOut, "  R_RegisterCCallable(\"%s\",\"%sdydt\",(DL_FUNC) %sdydt);\n", libname, prefix, prefix);
