@@ -26,6 +26,12 @@ extern "C" SEXP getRxode2ParseDf(void) {
   return getTran();
 }
 
+extern "C" SEXP getRxode2ParseGetPointerAssignment(void) {
+  loadQs();
+  Rcpp::Function getPtr = Rcpp::as<Rcpp::Function>(rxode2parseNs["rxode2parseGetPointerAssignment"]);
+  return getPtr();
+}
+
 //[[Rcpp::export]]
 Rcpp::CharacterVector rxQs(SEXP const x) {
   loadQs();
